==> schedwisrv-0.1.3.tar.gz: schedwisrv-0.1.3/py/tables/environment_var_s.py <==
# Schedwi
# Copyright (C) 2011 Herve Quatremain
# 
# This file is part of Schedwi.
# 
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
# 
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy import Column, Integer, String, ForeignKey
from sqlalchemy.schema import ForeignKeyConstraint

from base import Base

class environment_var_s(Base):
    __tablename__ = 'environment_var_s'
    __table_args__ = (
            ForeignKeyConstraint(
                        ['env_id', 'workload_date'],
                        ['environments_s.id', 'environments_s.workload_date']),
            {})

    env_id = Column(Integer, primary_key=True)
    position = Column(Integer, primary_key=True)
    env_key = Column(String(255))
    env_value = Column(String(255))
    workload_date = Column(Integer, primary_key=True)

    def __init__(self, position, env_key, env_value, workload_date):
        self.position = position
        self.env_key = env_key
        self.env_value = env_value
        self.workload_date = workload_date

    def copy(self):
        return environment_var(self.position, self.env_key, self.env_value,
                               self.workload_date)

==> schedwisrv-0.1.4.tar.gz: schedwisrv-0.1.4/py/tables/environment_var_s.py <==
# Schedwi
# Copyright (C) 2011, 2012 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy.schema import Column, ForeignKeyConstraint
from sqlalchemy.types import Integer, String

from base import Base, convert2unicode


class environment_var_s(Base):
    __tablename__ = 'environment_var_s'
    __table_args__ = (
            ForeignKeyConstraint(
                        ['env_id', 'workload_date'],
                        ['environments_s.id', 'environments_s.workload_date']),
            {})

    env_id = Column(Integer, primary_key=True)
    position = Column(Integer, primary_key=True)
    env_key = Column(String(255))
    env_value = Column(String(255))
    workload_date = Column(Integer, primary_key=True)

    def __init__(self, position, env_key, env_value, workload_date):
        self.position = position
        self.env_key = convert2unicode(env_key)
        self.env_value = convert2unicode(env_value)
        self.workload_date = workload_date

    def copy(self):
        return environment_var_s(self.position, self.env_key, self.env_value,
                                 self.workload_date)
